@@ -19,19 +19,20 @@ class MySqlDumpRunner:
             raise DependencyError( "mysqldump", "The 'mysqldump' client must be present in the $PATH")
 
     def __get_base_params(self):
-        return self.additional_opts + ["--host", self.db_host, "--port", self.db_port, "--user", self.db_user, f"-p{self.db_pass}"]
+        return ["--host", self.db_host, "--port", self.db_port, "--user", self.db_user, f"-p{self.db_pass}"]
 
     def open_dumper(self):
-        return subprocess.Popen(["mysqldump"] + self.__get_base_params() + [self.db_name], stdout=subprocess.PIPE).stdout
+        return subprocess.Popen(["mysqldump"] + self.__get_base_params() + self.additional_opts + [self.db_name], stdout=subprocess.PIPE).stdout
 
 
 class MySqlCmdRunner:
-    def __init__(self, db_host, db_user, db_pass, db_name, db_port="3306"):
+    def __init__(self, db_host, db_user, db_pass, db_name, db_port="3306", additional_opts = ""):
         self.db_host = db_host
         self.db_user = db_user
         self.db_pass = db_pass
         self.db_name = db_name
         self.db_port = db_port
+        self.additional_opts = shlex.split(additional_opts)
 
         if not (shutil.which("mysql")):
             raise DependencyError("mysql", "The 'mysql' client must be present in the $PATH")
@@ -58,7 +59,7 @@ class MySqlCmdRunner:
 
         for statement in statements:
             try:
-                outputs.append( subprocess.check_output(self.__get_base_params() + ["--execute", statement]) )
+                outputs.append( subprocess.check_output(self.__get_base_params() + self.additional_opts + ["--execute", statement]) )
             except subprocess.CalledProcessError as error:
                 self.__mask_subprocess_error(error)
 
@@ -72,7 +73,7 @@ class MySqlCmdRunner:
 
         for statement in statements:
             try:
-                outputs.append( subprocess.check_output(self.__get_base_params() + [self.db_name,  "--execute", statement]) )
+                outputs.append( subprocess.check_output(self.__get_base_params() + self.additional_opts + [self.db_name,  "--execute", statement]) )
             except subprocess.CalledProcessError as error:
                 self.__mask_subprocess_error(error)
 
@@ -80,9 +81,9 @@ class MySqlCmdRunner:
 
     def get_single_result(self, statement):
         try:
-            return subprocess.check_output(self.__get_base_params() + ["-sN", self.db_name, "--execute", statement]).decode()
+            return subprocess.check_output(self.__get_base_params() + ["-sN", *self.additional_opts, self.db_name, "--execute", statement]).decode()
         except subprocess.CalledProcessError as error:
             self.__mask_subprocess_error(error)
 
     def open_batch_processor(self):
-        return subprocess.Popen(self.__get_base_params() + [self.db_name], stdin=subprocess.PIPE).stdin
+        return subprocess.Popen(self.__get_base_params() + self.additional_opts + [self.db_name], stdin=subprocess.PIPE).stdin
